library(testthat)
library(spatstat.explore)
library(spatstat.geom)
library(onpoint)

test_check("onpoint")
